Struct network::protocols::direct_send::Message [−][src]
pub struct Message {
pub protocol_id: ProtocolId,
pub mdata: Bytes,
}Fields
protocol_id: ProtocolIdThe ProtocolId for which of our upstream application modules should
handle (i.e., deserialize and then respond to) this inbound rpc request.
For example, if protocol_id == ProtocolId::ConsensusRpcBcs, then this
inbound rpc request will be dispatched to consensus for handling.
mdata: BytesThe serialized request data received from the sender. At this layer in the stack, the request data is just an opaque blob and will only be fully deserialized later in the handling application module.